from services.basicservice import BasicService
import os
from servicestub import ServiceStub
from singleton import Singleton


class DiscountCounters(BasicService, metaclass=Singleton):
    versionPath = '/version'
    countersByCardPath = '/v1/destinations/%s/counters'
    sendCountersPath = '/v1/operations'
    sendCountersMultiPath = '/v1/operations/multi'
    countersByIdPath = '/v1/operations/additional/increment'

    def __init__(self):
        super().__init__(os.path.dirname(os.path.abspath(__file__)))

    def registerRoutes(self, servicestub: ServiceStub):
        self.log.info('Регистрация сервиса')
        self._loadCases('cases.json')

        servicestub.route(DiscountCounters.versionPath, method='GET', callback=self.ping)
        servicestub.route(DiscountCounters.countersByCardPath % '<cardNumber>',
                method='GET', callback=self.getCountersByCardNumber)
        servicestub.route(DiscountCounters.sendCountersPath, method='POST', callback=self.operations)
        servicestub.route(DiscountCounters.sendCountersMultiPath, method='POST', callback=self.operationsMulti)
        servicestub.route(DiscountCounters.countersByIdPath, method='POST', callback=self.increment)

    def ping(self):
        return self._createResponse(DiscountCounters.versionPath)

    def getCountersByCardNumber(self, cardNumber=''):
        self.log.info("Запрос счётчиков по номеру карты: '%s'" % cardNumber)
        methodPath = DiscountCounters.countersByCardPath % cardNumber
        if methodPath not in self.cases:
            methodPath = DiscountCounters.countersByCardPath % '<cardNumber>'
        return self._createResponse(methodPath)

    def operations(self):
        return self._createResponse(DiscountCounters.sendCountersPath)

    def operationsMulti(self):
        return self._createResponse(DiscountCounters.sendCountersMultiPath)

    def increment(self):
        return self._createResponse(DiscountCounters.countersByIdPath)


instance = DiscountCounters()
