from configparser import ConfigParser
from services.basicservice import BasicService
from servicestub import ServiceStub
from singleton import Singleton
from typing import Dict, List, Any
import bottle
import json
import os


class NoChange(BasicService, metaclass=Singleton):
    cases: Dict[str, List[Dict[str, Any]]]
    calcMethod = 'retail/v1/receipt/calculation/'
    receiptMethod = 'retail/v1/receipt/'

    def __init__(self):
        super().__init__(os.path.dirname(os.path.abspath(__file__)))

    def registerRoutes(self, servicestub: ServiceStub):
        self.log.info('Регистрация сервиса')
        self._loadCases('cases.json')

        conf = ConfigParser()
        conf.read(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'config.ini'))
        self.servicePath = conf.get('nochange', 'path') if conf.has_option('nochange', 'path') else '/nochange'

        servicestub.route(os.path.join(self.servicePath, NoChange.calcMethod),
                method='POST', callback=self.calculation)
        servicestub.route(os.path.join(self.servicePath, NoChange.receiptMethod),
                method='POST', callback=self.receipt)

    def calculation(self):
        body = json.loads(bottle.request.body.read())
        self.log.info("Данные запроса '%s'" % str(body))
        return self._createResponse(NoChange.calcMethod)

    def receipt(self):
        body = json.loads(bottle.request.body.read())
        self.log.info("Данные запроса '%s'" % str(body))
        return self._createResponse(NoChange.receiptMethod)


instance = NoChange()
